.. _tensor_module:

=======
Tensors
=======

.. automodule:: diofant.tensor

.. toctree::
    :caption: Contents
    :name: tenstoc
    :maxdepth: 3

    array.rst
    indexed.rst
    index_methods.rst
    tensor.rst
